# coding: utf-8

"""
    DataCore API  - Sport

    For more details, see openapi/init.py

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing_extensions import Annotated, Self

from atriumsports.datacore.openapi.models.social_media import SocialMedia
from atriumsports.datacore.openapi.models.venue_address import VenueAddress
from atriumsports.datacore.openapi.models.venue_historical_name import VenueHistoricalName


class VenuePostBody(BaseModel):
    """
    VenuePostBody
    """  # noqa: E501

    venue_id: Optional[StrictStr] = Field(
        default=None, description="The unique identifier of the venue", alias="venueId"
    )
    site_id: Optional[StrictStr] = Field(
        default=None, description="The site that this venue belongs to", alias="siteId"
    )
    abbreviation_local: Optional[Annotated[str, Field(strict=True, max_length=30)]] = Field(
        default=None,
        description="An abbreviation/short name in the [local](#section/Introduction/Character-Sets-and-Names) language",
        alias="abbreviationLocal",
    )
    name_local: Annotated[str, Field(strict=True, max_length=150)] = Field(
        description="The name of the venue in the [local](#section/Introduction/Character-Sets-and-Names) language",
        alias="nameLocal",
    )
    status: Optional[Annotated[str, Field(strict=True, max_length=30)]] = Field(
        default="ACTIVE", description="Status >- `ACTIVE` Active >- `INACTIVE` Inactive >- `PENDING` Pending "
    )
    alternate_name_local: Optional[Annotated[str, Field(strict=True, max_length=150)]] = Field(
        default=None, description="The alternate name of the venue, in Local Language", alias="alternateNameLocal"
    )
    abbreviation_latin: Optional[Annotated[str, Field(strict=True, max_length=30)]] = Field(
        default=None,
        description="An abbreviation/short name in [latin](#section/Introduction/Character-Sets-and-Names) characters",
        alias="abbreviationLatin",
    )
    name_latin: Optional[Annotated[str, Field(strict=True, max_length=150)]] = Field(
        default=None,
        description="The name of the venue in [latin](#section/Introduction/Character-Sets-and-Names) characters",
        alias="nameLatin",
    )
    alternate_name_latin: Optional[Annotated[str, Field(strict=True, max_length=150)]] = Field(
        default=None, description="The alternate name of the venue, in Latin characters", alias="alternateNameLatin"
    )
    country_code: Optional[Annotated[str, Field(min_length=3, strict=True, max_length=3)]] = Field(
        default=None,
        description="Country code of the venue. We recommend you use ISO-3166-1:alpha3 (upper case) values where available.",
        alias="countryCode",
    )
    timezone: Annotated[str, Field(strict=True, max_length=150)] = Field(
        description="Timezone of the venue.  The name of the zone as defined by the IANA TZ database. https://en.wikipedia.org/wiki/List_of_tz_database_time_zones"
    )
    address: Optional[VenueAddress] = None
    social: Optional[SocialMedia] = None
    capacity: Optional[StrictInt] = Field(
        default=None,
        description="This is the maximum number of people allowed for the venue in normal use. Certain events/configurations of the venue may cause this capacity to be increased/decreased - this is not reflected in this value.",
    )
    historical_names: Optional[List[VenueHistoricalName]] = Field(
        default=None, description="Array of venue historical names", alias="historicalNames"
    )
    external_id: Optional[Annotated[str, Field(strict=True, max_length=150)]] = Field(
        default=None, description="The Id of the data as set by the provider of the data", alias="externalId"
    )
    __properties: ClassVar[List[str]] = [
        "venueId",
        "siteId",
        "abbreviationLocal",
        "nameLocal",
        "status",
        "alternateNameLocal",
        "abbreviationLatin",
        "nameLatin",
        "alternateNameLatin",
        "countryCode",
        "timezone",
        "address",
        "social",
        "capacity",
        "historicalNames",
        "externalId",
    ]

    @field_validator("status")
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(["ACTIVE", "INACTIVE", "PENDING"]):
            raise ValueError("must be one of enum values ('ACTIVE', 'INACTIVE', 'PENDING')")
        return value

    @field_validator("external_id")
    def external_id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^[0-9A-Za-z\/_-]+$", value):
            raise ValueError(r"must validate the regular expression /^[0-9A-Za-z\/_-]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VenuePostBody from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of address
        if self.address:
            _dict["address"] = self.address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of social
        if self.social:
            _dict["social"] = self.social.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in historical_names (list)
        _items = []
        if self.historical_names:
            for _item_historical_names in self.historical_names:
                if _item_historical_names:
                    _items.append(_item_historical_names.to_dict())
            _dict["historicalNames"] = _items
        # set to None if site_id (nullable) is None
        # and model_fields_set contains the field
        if self.site_id is None and "site_id" in self.model_fields_set:
            _dict["siteId"] = None

        # set to None if abbreviation_local (nullable) is None
        # and model_fields_set contains the field
        if self.abbreviation_local is None and "abbreviation_local" in self.model_fields_set:
            _dict["abbreviationLocal"] = None

        # set to None if alternate_name_local (nullable) is None
        # and model_fields_set contains the field
        if self.alternate_name_local is None and "alternate_name_local" in self.model_fields_set:
            _dict["alternateNameLocal"] = None

        # set to None if abbreviation_latin (nullable) is None
        # and model_fields_set contains the field
        if self.abbreviation_latin is None and "abbreviation_latin" in self.model_fields_set:
            _dict["abbreviationLatin"] = None

        # set to None if name_latin (nullable) is None
        # and model_fields_set contains the field
        if self.name_latin is None and "name_latin" in self.model_fields_set:
            _dict["nameLatin"] = None

        # set to None if alternate_name_latin (nullable) is None
        # and model_fields_set contains the field
        if self.alternate_name_latin is None and "alternate_name_latin" in self.model_fields_set:
            _dict["alternateNameLatin"] = None

        # set to None if country_code (nullable) is None
        # and model_fields_set contains the field
        if self.country_code is None and "country_code" in self.model_fields_set:
            _dict["countryCode"] = None

        # set to None if address (nullable) is None
        # and model_fields_set contains the field
        if self.address is None and "address" in self.model_fields_set:
            _dict["address"] = None

        # set to None if social (nullable) is None
        # and model_fields_set contains the field
        if self.social is None and "social" in self.model_fields_set:
            _dict["social"] = None

        # set to None if capacity (nullable) is None
        # and model_fields_set contains the field
        if self.capacity is None and "capacity" in self.model_fields_set:
            _dict["capacity"] = None

        # set to None if historical_names (nullable) is None
        # and model_fields_set contains the field
        if self.historical_names is None and "historical_names" in self.model_fields_set:
            _dict["historicalNames"] = None

        # set to None if external_id (nullable) is None
        # and model_fields_set contains the field
        if self.external_id is None and "external_id" in self.model_fields_set:
            _dict["externalId"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VenuePostBody from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "venueId": obj.get("venueId"),
                "siteId": obj.get("siteId"),
                "abbreviationLocal": obj.get("abbreviationLocal"),
                "nameLocal": obj.get("nameLocal"),
                "status": obj.get("status") if obj.get("status") is not None else "ACTIVE",
                "alternateNameLocal": obj.get("alternateNameLocal"),
                "abbreviationLatin": obj.get("abbreviationLatin"),
                "nameLatin": obj.get("nameLatin"),
                "alternateNameLatin": obj.get("alternateNameLatin"),
                "countryCode": obj.get("countryCode"),
                "timezone": obj.get("timezone"),
                "address": VenueAddress.from_dict(obj["address"]) if obj.get("address") is not None else None,
                "social": SocialMedia.from_dict(obj["social"]) if obj.get("social") is not None else None,
                "capacity": obj.get("capacity"),
                "historicalNames": (
                    [VenueHistoricalName.from_dict(_item) for _item in obj["historicalNames"]]
                    if obj.get("historicalNames") is not None
                    else None
                ),
                "externalId": obj.get("externalId"),
            }
        )
        return _obj
